Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(520)

Unified Diff: webkit/browser/fileapi/file_system_backend.h

Issue 18344013: fileapi: Rename FileSystemMountProvider to FileSystemBackend (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/browser/fileapi/file_system_backend.h
diff --git a/webkit/browser/fileapi/file_system_mount_point_provider.h b/webkit/browser/fileapi/file_system_backend.h
similarity index 91%
rename from webkit/browser/fileapi/file_system_mount_point_provider.h
rename to webkit/browser/fileapi/file_system_backend.h
index eaaf4718c6e43e4cac5dc7711cf06488ad05151c..b5013d6aecaa9bb6844c6bf917b9dd977eaf666f 100644
--- a/webkit/browser/fileapi/file_system_mount_point_provider.h
+++ b/webkit/browser/fileapi/file_system_backend.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef WEBKIT_BROWSER_FILEAPI_FILE_SYSTEM_MOUNT_POINT_PROVIDER_H_
-#define WEBKIT_BROWSER_FILEAPI_FILE_SYSTEM_MOUNT_POINT_PROVIDER_H_
+#ifndef WEBKIT_BROWSER_FILEAPI_FILE_SYSTEM_BACKEND_H_
+#define WEBKIT_BROWSER_FILEAPI_FILE_SYSTEM_BACKEND_H_
#include <string>
#include <vector>
@@ -35,20 +35,19 @@ class FileSystemOperation;
class FileSystemQuotaUtil;
class RemoteFileSystemProxyInterface;
-// An interface to provide mount-point-specific path-related utilities
-// and specialized FileSystemFileUtil instance.
+// An interface for defining a file system backend.
//
// NOTE: when you implement a new MountPointProvider for your own
// FileSystem module, please contact to kinuko@chromium.org.
//
-class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemMountPointProvider {
+class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemBackend {
public:
// Callback for OpenFileSystem.
typedef base::Callback<void(base::PlatformFileError error)>
OpenFileSystemCallback;
typedef base::Callback<void(base::PlatformFileError error)>
DeleteFileSystemCallback;
- virtual ~FileSystemMountPointProvider() {}
+ virtual ~FileSystemBackend() {}
// Returns true if this mount point provider can handle |type|.
// One mount point provider may be able to handle multiple filesystem types.
@@ -127,8 +126,8 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemMountPointProvider {
};
// An interface to control external file system access permissions.
-class ExternalFileSystemMountPointProvider
- : public FileSystemMountPointProvider {
+class ExternalFileSystemBackend
+ : public FileSystemBackend {
kinuko 2013/07/04 07:12:23 Ah... I think this one is more like MountPointProv
satorux1 2013/07/04 08:11:32 Added a TODO here with the bug you filed.
public:
// Returns true if |url| is allowed to be accessed.
// This is supposed to perform ExternalFileSystem-specific security
@@ -156,4 +155,4 @@ class ExternalFileSystemMountPointProvider
} // namespace fileapi
-#endif // WEBKIT_BROWSER_FILEAPI_FILE_SYSTEM_MOUNT_POINT_PROVIDER_H_
+#endif // WEBKIT_BROWSER_FILEAPI_FILE_SYSTEM_BACKEND_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -35,20 +35,19 @@ class FileSystemOperation;
//
-// NOTE: when you implement a new MountPointProvider for your own
+// NOTE: when you implement a new FileSystemBackend for your own
// FileSystem module, please contact to kinuko@chromium.org.
//